@@ -37,7 +37,7 @@
 
 static const char * const balance_cmd_group_usage[] = {
 	"btrfs balance <command> [options] <path>",
-	"btrfs balance <path>",
+	"btrfs balance <path>        (deprecated, use 'btrfs balance start')",
 	NULL
 };
 
@@ -865,10 +865,27 @@ static const struct cmd_group balance_cmd_group = {
 
 static int cmd_balance(const struct cmd_struct *cmd, int argc, char **argv)
 {
-	if (argc == 2 && strcmp("start", argv[1]) != 0) {
-		/* old 'btrfs filesystem balance <path>' syntax */
+	bool old_syntax = true;
+
+	/*
+	 * Exclude all valid subcommands from being potentially confused as path
+	 * for the obsolete syntax: btrfs balance <path>
+	 */
+	if (argc == 2) {
+		for (int i = 0; balance_cmd_group.commands[i] != NULL; i++) {
+			if (strcmp(argv[1], balance_cmd_group.commands[i]->token) == 0) {
+				old_syntax = false;
+				break;
+			}
+		}
+	} else {
+		old_syntax = false;
+	}
+
+	if (old_syntax) {
 		struct btrfs_ioctl_balance_args args;
 
+		warning("deprecated syntax, please use 'btrfs balance start'");
 		memset(&args, 0, sizeof(args));
 		args.flags |= BTRFS_BALANCE_TYPE_MASK;
 
